@@ -8,10 +8,14 @@ import re
 input_path = 'psychopy/CHANGELOG.txt'
 output_path = 'docs/source/changelog.rst'
 
-def repl_hash(m):
+def repl_issue(m):
     g = m.group(1)
     return g.replace('#', '`#') +  " <https://github.com/psychopy/psychopy/issues/" + g.strip(' (#') + ">`_"
 
+def repl_commit(m):
+    g = m.group(1)
+    return g.replace('#', '`commit:')[:18] +  " <https://github.com/psychopy/psychopy/commit/" + g.strip(' (#') + ">`_"
+
 def repl_blue(m):
     g = m.group(1)
     g = g.replace('`', "'")
@@ -21,9 +25,13 @@ def repl_blue(m):
 txt = open(input_path, "rU").read()
 
 # programmatic replacements:
-hashtag = re.compile(r"([ (]#\d{3,4})\b")
-print "found %i hashtags" %(len(hashtag.findall(txt)))
-txt_hash = hashtag.sub(repl_hash, txt)
+hashtag = re.compile(r"([ (]#\d{3,5})\b")
+print "found %i issue tags" %(len(hashtag.findall(txt)))
+txt_hash = hashtag.sub(repl_issue, txt)
+
+hashtag = re.compile(r"([ (]#[0-9a-f]{6,})\b")
+print "found %i commit tags" %(len(hashtag.findall(txt_hash)))
+txt_hash = hashtag.sub(repl_commit, txt_hash)
 
 blue = re.compile(r"(CHANGE.*)\n")
 print "found %i CHANGE" %(len(blue.findall(txt_hash)))
