@@ -1,8 +1,11 @@
 #!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-"""Demo: show a very basic program: hello world
 """
+Demo: show a very basic program: hello world
+"""
+
+from __future__ import division
 
 # Import key parts of the PsychoPy library:
 from psychopy import visual, core
@@ -23,4 +26,8 @@ win.flip()
 
 # Wait 3 seconds so people can see the message, then exit gracefully:
 core.wait(3)
+
 win.close()
+core.quit()
+
+# The contents of this file are in the public domain.
