@@ -2,9 +2,9 @@
 http://www.curdes.com/
 This class is only useful when the fORP is connected via the serial port.
 
-If you're connecting via USB, just treat it like a standard keyboard. E.g., use
-a Keyboard component, and typically listen for Allowed keys ``'1', '2', '3', '4', '5'``.
-Or use ``event.getKeys()``.
+If you're connecting via USB, just treat it like a standard keyboard.
+E.g., use a Keyboard component, and typically listen for Allowed keys
+``'1', '2', '3', '4', '5'``. Or use ``event.getKeys()``.
 """
 
 # Part of the PsychoPy library
@@ -17,8 +17,10 @@ from psychopy import logging, event
 import sys
 from collections import defaultdict
 
-try: import serial
-except: serial=False
+try:
+    import serial
+except ImportError:
+    serial = False
 
 BUTTON_BLUE = 1
 BUTTON_YELLOW = 2
@@ -34,18 +36,20 @@ BUTTON_MAP = [
     (0x10, BUTTON_TRIGGER)]
 
 
-class ButtonBox:
+class ButtonBox(object):
     """Serial line interface to the fORP MRI response box.
 
-    To use this object class, select the box use setting `serialPort`, and connect
-    the serial line. To emulate key presses with a serial connection, use `getEvents(asKeys=True)`
-    (e.g., to be able to use a RatingScale object during scanning).
-    Alternatively connect the USB cable and use fORP to emulate a keyboard.
+    To use this object class, select the box use setting `serialPort`,
+    and connect the serial line. To emulate key presses with a serial
+    connection, use `getEvents(asKeys=True)` (e.g., to be able to use
+    a RatingScale object during scanning). Alternatively connect the USB
+    cable and use fORP to emulate a keyboard.
 
-    fORP sends characters at 800Hz, so you should check the buffer frequently.
-    Also note that the trigger event numpy the fORP is typically extremely short
-    (occurs for a single 800Hz epoch).
+    fORP sends characters at 800Hz, so you should check the buffer
+    frequently. Also note that the trigger event numpy the fORP is
+    typically extremely short (occurs for a single 800Hz epoch).
     """
+
     def __init__(self, serialPort=1, baudrate=19200):
         """
         :Parameters:
@@ -55,16 +59,19 @@ class ButtonBox:
             `baud` :
                 the communication rate (baud), eg, 57600
         """
+        super(ButtonBox, self).__init__()
         if not serial:
-            raise ImportError('The module serial is needed to connect to fORP. ' +\
-                "On most systems this can be installed with\n\t easy_install pyserial")
+            raise ImportError("The module serial is needed to connect to "
+                              "fORP. On most systems this can be installed "
+                              "with\n\t easy_install pyserial")
 
-        self.port = serial.Serial(serialPort-1, baudrate=baudrate, bytesize=8,
-                                  parity='N', stopbits=1, timeout=0.001)
+        self.port = serial.Serial(serialPort - 1, baudrate=baudrate,
+                                  bytesize=8, parity='N', stopbits=1,
+                                  timeout=0.001)
         if not self.port.isOpen():
             self.port.open()
 
-        self.buttonStatus = defaultdict(bool) # Defaults to False
+        self.buttonStatus = defaultdict(bool)  # Defaults to False
         self.rawEvts = []
         self.pressEvents = []
 
@@ -81,16 +88,16 @@ class ButtonBox:
 
     def getEvents(self, returnRaw=False, asKeys=False, allowRepeats=False):
         """Returns a list of unique events (one event per button pressed)
-        and also stores a copy of the full list of events since last getEvents()
-        (stored as ForpBox.rawEvts)
+        and also stores a copy of the full list of events since last
+        getEvents() (stored as ForpBox.rawEvts)
 
         `returnRaw` :
             return (not just store) the full event list
 
         `asKeys` :
-            If True, will also emulate pyglet keyboard events, so that button 1
-            will register as a keyboard event with value "1", and as such will
-            be detectable using `event.getKeys()`
+            If True, will also emulate pyglet keyboard events, so that
+            button 1 will register as a keyboard event with value "1",
+            and as such will be detectable using `event.getKeys()`
 
         `allowRepeats` :
             If True, this will return pressed buttons even if they were held
@@ -108,7 +115,8 @@ class ButtonBox:
         self.pressEvents = []
         if allowRepeats:
             self.clearStatus()
-        #for each character convert to an ordinal int value (numpy the ascii chr)
+        # for each character convert to an ordinal int value (numpy the ascii
+        # chr)
         for thisChr in evtStr:
             pressCode = ord(thisChr)
             self.rawEvts.append(pressCode)
@@ -117,9 +125,10 @@ class ButtonBox:
             if asKeys:
                 for code in decodedEvents:
                     event._onPygletKey(symbol=code, modifiers=None)
-                    # better as: emulated='fORP_bbox_asKey', but need to adjust event._onPygletKey
-                    # and the symbol conversion pyglet.window.key.symbol_string(symbol).lower()
-        #return the abbreviated list if necessary
+                    # better as: emulated='fORP_bbox_asKey', but need to
+                    # adjust event._onPygletKey and the symbol conversion
+                    # pyglet.window.key.symbol_string(symbol).lower()
+        # return the abbreviated list if necessary
         if returnRaw:
             return self.rawEvts
         else:
@@ -152,16 +161,16 @@ class ButtonBox:
 
         `pressCode` :
             A number with a bit set for every button currently pressed. Will
-            be between 0 and 31."""
+            be between 0 and 31.
+        """
 
         return [(mapping[1], bool(mapping[0] & pressCode))
-            for mapping in BUTTON_MAP]
-
+                for mapping in BUTTON_MAP]
 
     def getUniqueEvents(self, fullEvts=False):
         """Returns a Python set of the unique (unordered) events of either
-        a list given or the current rawEvts buffer"""
-
+        a list given or the current rawEvts buffer
+        """
         if fullEvts:
             return set(self.rawEvts)
         return set(self.pressEvents)
