@@ -1062,9 +1062,10 @@ try:
         # Sample Filter Types        
         FILTER_FILE=10
         FILTER_NET=11
+        FILTER_ONLINE=11
         FILTER_SERIAL=12
         FILTER_ANALOG=13
-        FILTER_ALL=14
+        FILTER_ALL=15
     
         #
         ## Eye Type Constants
@@ -1186,7 +1187,7 @@ try:
     XInputBatteryTypeConstants.initialize() 
     try:
         XInputBatteryTypeConstants._keys.remove(XInputBatteryTypeConstants.getID('UNDEFINED'))
-    except:
+    except Exception:
         pass
     
     class XInputBatteryLevelConstants(Constants):
@@ -1199,7 +1200,7 @@ try:
     XInputBatteryLevelConstants.initialize()
     try:
         XInputBatteryLevelConstants._keys.remove(XInputBatteryLevelConstants.getID('UNDEFINED'))
-    except:
+    except Exception:
         pass
 
     class XInputCapabilitiesConstants(Constants):
@@ -1363,7 +1364,7 @@ try:
     XInputCapabilitiesConstants.initialize()
     try:
         XInputCapabilitiesConstants._keys.remove(XInputCapabilitiesConstants.getID('UNDEFINED'))
-    except:
+    except Exception:
         pass
     
     class XInputGamePadConstants(Constants):
@@ -1389,10 +1390,10 @@ try:
     XInputGamePadConstants.initialize()
     try:
         XInputGamePadConstants._keys.remove(XInputGamePadConstants.getID('UNDEFINED'))
-    except:
+    except Exception:
         pass
             
-except:
+except Exception:
     import traceback
     traceback.print_exc()
     #from . import printExceptionDetailsToStdErr
