@@ -10,9 +10,9 @@ Distributed under the terms of the GNU General Public License (GPL version 3 or
 .. fileauthor:: Sol Simpson <sol@isolver-software.com>
 """
 
-from ... import print2err, createErrorResult
-from .. import Device,ioDeviceError
-from ...constants import DeviceConstants,EyeTrackerConstants
+from ... import print2err
+from .. import Device, ioDeviceError
+from ...constants import DeviceConstants, EyeTrackerConstants
 import hw
 
 
@@ -269,30 +269,8 @@ class EyeTrackerDevice(Device):
                  * EyeTrackerConstants.EYETRACKER_ERROR if this method is supported and starting_state is, but an error occurred during the method (other than a failed calibration or drift correct result).
                  * EyeTrackerConstants.EYETRACKER_INTERFACE_METHOD_NOT_SUPPORTED if the eye tracker implementation does not support this method or the specified starting_state.
         """
-        
-        # Implementation Note: Change this list to only include the states your eye tracker can support.
-        IMPLEMENTATION_SUPPORTED_STATES=[EyeTrackerConstants.getName(EyeTrackerConstants.DEFAULT_SETUP_PROCEDURE),
-                                         EyeTrackerConstants.getName(EyeTrackerConstants.CALIBRATION_START_STATE),
-                                         EyeTrackerConstants.getName(EyeTrackerConstants.VALIDATION_START_STATE)]
-        
-        if starting_state in IMPLEMENTATION_SUPPORTED_STATES:
+        return EyeTrackerConstants.EYETRACKER_INTERFACE_METHOD_NOT_SUPPORTED
 
-            if starting_state == EyeTrackerConstants.getName(EyeTrackerConstants.DEFAULT_SETUP_PROCEDURE):
-                # Implementation Note: Run your custom implementation logic for the method here
-                print2err("EyeTracker should handle runSetupProcedure method with starting_state of {0} now.".format(starting_state))
-                
-                # Implementation Note: result should be changed to return one of
-                #       EyeTrackerConstants.EYETRACKER_OK 
-                #       EyeTrackerConstants.EYETRACKER_CALIBRATION_ERROR 
-                #       EyeTrackerConstants.EYETRACKER_ERROR 
-                result = EyeTrackerConstants.EYETRACKER_INTERFACE_METHOD_NOT_SUPPORTED
-                return result
-            else:
-                return EyeTrackerConstants.EYETRACKER_INTERFACE_METHOD_NOT_SUPPORTED
-        else:
-            return createErrorResult("INVALID_METHOD_ARGUMENT_VALUE",error_message="The starting_state arguement value provided is not recognized",method="EyeTracker.runSetupProcedure",arguement='starting_state', value=starting_state)            
-
-                
     def setRecordingState(self,recording):
         """
         The setRecordingState method is used to start or stop the recording 
@@ -305,10 +283,6 @@ class EyeTrackerDevice(Device):
         Return:
             bool: the current recording state of the eye tracking device
         """
-        
-        if not isinstance(recording,bool):
-            return createErrorResult("INVALID_METHOD_ARGUMENT_VALUE",error_message="The recording arguement value provided is not a boolean.",method="EyeTracker.setRecordingState",arguement='recording', value=recording)
-        
         # Implementation Note: Perform your implementation specific logic for this method here
         print2err("EyeTracker should handle setRecordingState method with recording value of {0} now.".format(recording))
         
@@ -382,7 +356,14 @@ class EyeTrackerDevice(Device):
         """
         return self._latest_gaze_position
 
-
+    def getPosition(self):
+        """
+        The getPosition method is the same as the getLastGazePosition method,
+        provided as a consistent cross device method to access the current screen
+        position reported by a device. See getLastGazePosition for further details.
+        """
+        return self._latest_gaze_position
+        
     def _eyeTrackerToDisplayCoords(self,eyetracker_point):
         """
         The _eyeTrackerToDisplayCoords method is required for implementation
