@@ -15,7 +15,7 @@ import msgpack
 try:
     import msgpack_numpy as m
     m.patch()
-except:
+except Exception:
     pass
 import struct
 from weakref import proxy
@@ -36,7 +36,7 @@ class SocketConnection(object):
         self._rcvBufferLength=rcvBufferLength
         self.lastAddress=None
         self.sock=None
-        self.initSocket()
+        self.initSocket(broadcast,blocking, timeout)
 
         self.coder=msgpack
         self.packer=msgpack.Packer()
@@ -66,7 +66,6 @@ class SocketConnection(object):
 
     def sendTo(self,data,address=None):
         if address is None:
-            #print2err('{0}: {1}'.format(self.__class__.__name__,address))
             address=self._remote_host, self._remote_port
         d=self.pack(data)
         byte_count=len(d)
@@ -99,15 +98,17 @@ class SocketConnection(object):
 
 
 class UDPClientConnection(SocketConnection):
-    def __init__(self,remote_host='127.0.0.1',remote_port=9000,rcvBufferLength = MAX_PACKET_SIZE,broadcast=False,blocking=1, timeout=1):
+    def __init__(self,remote_host='127.0.0.1',remote_port=9000,rcvBufferLength = MAX_PACKET_SIZE,broadcast=False,blocking=1, timeout=None):
         SocketConnection.__init__(self,remote_host=remote_host,remote_port=remote_port,rcvBufferLength=rcvBufferLength,broadcast=broadcast,blocking=blocking, timeout=timeout)
-    def initSocket(self,**kwargs):
+    def initSocket(self,broadcast,blocking, timeout):
         if Computer.is_iohub_process is True:
             from gevent import socket
         else:
             import socket
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, MAX_PACKET_SIZE)
+        self.sock.settimeout(timeout)
+        self.sock.setblocking(blocking)
 
 ##### TIME SYNC CLASS ######
  
