@@ -10,7 +10,6 @@ Distributed under the terms of the GNU General Public License (GPL version 3 or
 .. moduleauthor:: Sol Simpson <sol@isolver-software.com> + contributors, please see credits section of documentation.
 .. fileauthor:: Sol Simpson <sol@isolver-software.com>
 """
-
 import gevent
 from gevent.server import DatagramServer
 from gevent import Greenlet
@@ -24,21 +23,29 @@ from psychopy.iohub import print2err, printExceptionDetailsToStdErr, ioHubError
 from psychopy.iohub import DeviceConstants, EventConstants
 from psychopy.iohub import Computer, DeviceEvent, import_device
 from psychopy.iohub.devices.deviceConfigValidation import validateDeviceConfiguration
-from psychopy.iohub.net import MAX_PACKET_SIZE
 currentSec= Computer.currentSec
 
-import json
+try:
+    import ujson as json
+except Exception:
+    import json
+
 import msgpack
 try:
     import msgpack_numpy as m
     m.patch()
-except:
+except Exception:
     pass
 
 import psutil
 
+MAX_PACKET_SIZE = 64*1024
+
 class udpServer(DatagramServer):
     def __init__(self,ioHubServer,address,coder='msgpack'):
+        global MAX_PACKET_SIZE
+        import psychopy.iohub.net
+        MAX_PACKET_SIZE = psychopy.iohub.net.MAX_PACKET_SIZE
         self.iohub=ioHubServer
         self.feed=None
         self._running=True
@@ -85,7 +92,7 @@ class udpServer(DatagramServer):
             result=None
             try:
                 result=getattr(self,callable_name)
-            except:
+            except Exception:
                 print2err("RPC_ATTRIBUTE_ERROR")
                 printExceptionDetailsToStdErr()
                 self.sendResponse('RPC_ATTRIBUTE_ERROR',replyTo)
@@ -118,7 +125,7 @@ class udpServer(DatagramServer):
         elif request_type == 'STOP_IOHUB_SERVER':
             try:
                 self.shutDown()
-            except:
+            except Exception:
                 printExceptionDetailsToStdErr
         else:
             print2err("RPC_NOT_CALLABLE_ERROR")
@@ -128,6 +135,7 @@ class udpServer(DatagramServer):
             
     def handleGetEvents(self,replyTo):
         try:
+            self.iohub.processDeviceEvents()
             currentEvents=list(self.iohub.eventBuffer)
             self.iohub.eventBuffer.clear()
 
@@ -182,7 +190,7 @@ class udpServer(DatagramServer):
             
             try:
                 method=getattr(dev,dmethod)
-            except:
+            except Exception:
                 print2err("IOHUB_DEVICE_METHOD_ERROR")
                 printExceptionDetailsToStdErr()
                 self.sendResponse('IOHUB_DEVICE_METHOD_ERROR', replyTo)
@@ -281,7 +289,7 @@ class udpServer(DatagramServer):
                 self.socket.sendto(packet_data[(p+1)*max_size:packet_data_length],address)
             else:
                 self.socket.sendto(packet_data,address)
-        except:
+        except Exception:
             print2err('Error trying to send data to experiment process:')
             print2err('max_size: ',max_size)
             print2err('data length: ',packet_data_length)
@@ -296,7 +304,7 @@ class udpServer(DatagramServer):
                 print2err('Data was [{0}]'.format(data))     
                 try:    
                     first_data_element=data[0]
-                except:
+                except Exception:
                     pass
                     
             packet_data_length=0
@@ -323,7 +331,7 @@ class udpServer(DatagramServer):
             if self.iohub.emrt_file:
                 return self.iohub.emrt_file.checkIfSessionCodeExists(sessionCode)
             return False
-        except:
+        except Exception:
             printExceptionDetailsToStdErr()
 
     def registerPygletWindowHandles(self,*win_hwhds):
@@ -369,14 +377,40 @@ class udpServer(DatagramServer):
             return self.iohub.emrt_file._addRowToConditionVariableTable(experiment_id,session_id,data)
         return False
 
-    def clearEventBuffer(self):
-        return self.iohub.clearEventBuffer()
+    def clearEventBuffer(self, clear_device_level_buffers=False):
+        """
 
-    def enableHighPriority(self,disable_gc=True):
-        return Computer.enableHighPriority(disable_gc)
+        :param clear_device_level_buffers:
+        :return:
+        """
+        r = self.iohub.clearEventBuffer()
+        if clear_device_level_buffers is True:
+            for device in self.iohub.devices:
+                try:
+                    device.clearEvents(call_proc_events=False)
+                except Exception:
+                    pass
 
-    def disableHighPriority(self):
-        return Computer.disableHighPriority()
+    def getTime(self):
+        """
+        See Computer.getTime documentation, where current process will be
+        the ioHub Server process.
+        """
+        return Computer.getTime()
+
+    def setPriority(self, level='normal', disable_gc=False):
+        """
+        See Computer.setPriority documentation, where current process will be
+        the ioHub Server process.
+        """
+        return Computer.setPriority(level, disable_gc)
+
+    def getPriority(self):
+        """
+        See Computer.getPriority documentation, where current process will be
+        the ioHub Server process.
+        """
+        return Computer.getPriority()
 
     def getProcessAffinity(self):
         return Computer.getCurrentProcessAffinity()
@@ -392,11 +426,11 @@ class udpServer(DatagramServer):
 
     def shutDown(self):
         try:
-            self.disableHighPriority()
+            self.setPriority('normal')
             self.iohub.shutdown()
             self._running=False
             self.stop()
-        except:
+        except Exception:
             print2err("Error in ioSever.shutdown():")
             printExceptionDetailsToStdErr()
             sys.exit(1)
@@ -423,6 +457,7 @@ class DeviceMonitor(Greenlet):
     def __del__(self):
         self.device = None
 
+
 class ioServer(object):
     eventBuffer=None
     deviceDict={}
@@ -471,7 +506,7 @@ class ioServer(object):
                     self.createDataStoreFile(experiment_datastore_config.get('filename','events')+'.hdf5',resultsFilePath,'a',experiment_datastore_config)
 
                     #print2err("Created ioDataStore.")
-        except:
+        except Exception:
             print2err("Error during ioDataStore creation....")
             printExceptionDetailsToStdErr()
 
@@ -483,7 +518,7 @@ class ioServer(object):
                     #print2err("======================================================")
                     #print2err("Started load process for: {0}".format(device_class_name))
                     self.createNewMonitoredDevice(device_class_name,deviceConfig)
-        except:
+        except Exception:
             print2err("Error during device creation ....")
             printExceptionDetailsToStdErr()
             raise ioHubError("Error during device creation ....")
@@ -534,6 +569,15 @@ class ioServer(object):
                     device_errors[error_type]=error_list                
                     self._all_device_config_errors[device_module_path]=device_errors
 
+    def pumpMsgTasklet(self, sleep_interval):
+        import pythoncom
+        while self._running:
+            stime=Computer.getTime()
+            if pythoncom.PumpWaitingMessages() == 1:
+                break
+            dur = sleep_interval - (Computer.getTime()-stime)
+            gevent.sleep(max(0.0, dur))
+
     def createNewMonitoredDevice(self,device_class_name,deviceConfig):
         #print2err("#### createNewMonitoredDevice: ",device_class_name)
         self._all_device_config_errors=dict()
@@ -553,7 +597,7 @@ class ioServer(object):
                 print2err('## Device was not started by the ioHub Server: ',device_class_name)
                 raise ioHubError("Device config validation failed")
                 
-        except:
+        except Exception:
             print2err("Error during device creation ....")
             printExceptionDetailsToStdErr()
             raise ioHubError("Error during device creation ....")
@@ -564,7 +608,7 @@ class ioServer(object):
             try:            
                 if self.emrt_file is not None:
                     self.emrt_file.updateDataStoreStructure(device_instance,event_classes)
-            except:
+            except Exception:
                 print2err("Error while updating datastore for device addition:",device_instance,device_event_ids)
                 printExceptionDetailsToStdErr()
 
@@ -589,64 +633,24 @@ class ioServer(object):
         deviceDict=ioServer.deviceDict
         iohub=self
         if device_class_name in ('Mouse','Keyboard'):
-            if Computer.system == 'win32':  
-                if self._hookDevice is None:
-                    iohub.log("Creating pyHook Monitors....")
-                    #print2err("Creating pyHook Monitor....")
-    
-                    class pyHookDevice(object):
-                        def __init__(self):
-                            import pyHook
-                            self._hookManager=pyHook.HookManager()
-                            
-                            self._mouseHooked=False
-                            self._keyboardHooked=False
-                            
-                            if device_class_name == 'Mouse':
-                                #print2err("Hooking Mouse.....")
-                                self._hookManager.MouseAll = deviceDict['Mouse']._nativeEventCallback
-                                self._hookManager.HookMouse()
-                                self._mouseHooked=True
-                            elif device_class_name == 'Keyboard':
-                                #print2err("Hooking Keyboard.....")
-                                self._hookManager.KeyAll = deviceDict['Keyboard']._nativeEventCallback
-                                self._hookManager.HookKeyboard()
-                                self._keyboardHooked=True
-    
-                            #iohub.log("WindowsHook PumpEvents Periodic Timer Created.")
-                
-                        def _poll(self):
-                            import pythoncom
-                            # PumpWaitingMessages returns 1 if a WM_QUIT message was received, else 0
-                            if pythoncom.PumpWaitingMessages() == 1:
-                                raise KeyboardInterrupt()               
-        
-                        def __del__(self):
-                            #if self._mouseHooked and self._hookManager:
-                            #    self._hookManager.UnhookMouse()
-                            #elif self._keyboardHooked and self._hookManager:
-                            #    self._hookManager.UnhookKeyboard()
-                            self._hookManager=None
-                    #print2err("Creating pyHook Monitor......")
-                    self._hookDevice=pyHookDevice()
-                    hookMonitor=DeviceMonitor(self._hookDevice, self.config.get('windows_msgpump_interval', 0.00375))
-                    self.deviceMonitors.append(hookMonitor)
-                
-                    #print2err("Created pyHook Monitor.")
-                else:
-                    #print2err("UPDATING pyHook Monitor....")
-                    if device_class_name == 'Mouse' and self._hookDevice._mouseHooked is False:
-                        #print2err("Hooking Mouse.....")
-                        self._hookDevice._hookManager.MouseAll = deviceDict['Mouse']._nativeEventCallback
-                        self._hookDevice._hookManager.HookMouse()
-                        self._hookDevice._mouseHooked=True
-                    elif device_class_name == 'Keyboard' and self._hookDevice._keyboardHooked is False:
-                        #print2err("Hooking Keyboard.....")
-                        self._hookDevice._hookManager.KeyAll = deviceDict['Keyboard']._nativeEventCallback
-                        self._hookDevice._hookManager.HookKeyboard()
-                        self._hookDevice._keyboardHooked=True
-                
-                    #print2err("Finished Updating pyHook Monitor.")
+            if Computer.system == 'win32':
+                import pyHook
+                if self._hookManager is None:
+                    iohub.log("Creating pyHook HookManager....")
+                    #print2err("Creating pyHook HookManager....")
+                    self._hookManager = pyHook.HookManager()
+                    self._hookManager.keyboard_hook = False
+
+                if device_class_name == 'Mouse' and self._hookManager.mouse_hook is False:
+                    #print2err("Hooking Mouse.....")
+                    self._hookManager.MouseAll = ioServer.deviceDict['Mouse']._nativeEventCallback
+                    self._hookManager.HookMouse()
+
+                if device_class_name == 'Keyboard' and self._hookManager.keyboard_hook is False:
+                    #print2err("Hooking Keyboard.....")
+                    self._hookManager.KeyAll = ioServer.deviceDict['Keyboard']._nativeEventCallback
+                    self._hookManager.HookKeyboard()
+
                 
             elif Computer.system == 'linux2':
                 # TODO: consider switching to xlib-ctypes implementation of xlib
@@ -823,7 +827,7 @@ class ioServer(object):
                 exp.log(text,level,log_time)
             else:
                 self._logMessageBuffer.append((text,level,log_time))
-        except:
+        except Exception:
             printExceptionDetailsToStdErr()
             
     def createDataStoreFile(self,fileName,folderPath,fmode,ioHubsettings):
@@ -839,12 +843,14 @@ class ioServer(object):
             pytablesfile.flush()
             pytablesfile.close()
             
-    def processDeviceEvents(self,sleep_interval):
+    def processEventsTasklet(self,sleep_interval):
         while self._running:
-            self._processDeviceEventIteration()
-            gevent.sleep(sleep_interval)
+            stime=Computer.getTime()
+            self.processDeviceEvents()
+            dur = sleep_interval - (Computer.getTime()-stime)
+            gevent.sleep(max(0.0, dur))
 
-    def _processDeviceEventIteration(self):
+    def processDeviceEvents(self):
         for device in self.devices:
             try:
                 events = device._getNativeEventBuffer()
@@ -867,7 +873,7 @@ class ioServer(object):
                         l._handleEvent(e)
 
 
-            except:
+            except Exception:
                 printExceptionDetailsToStdErr()
                 print2err("Error in processDeviceEvents: ", device, " : ", len(events), " : ", e)
                 print2err("Event type ID: ",e[DeviceEvent.EVENT_TYPE_ID_INDEX], " : " , EventConstants.getName(e[DeviceEvent.EVENT_TYPE_ID_INDEX]))
@@ -876,7 +882,9 @@ class ioServer(object):
     def _handleEvent(self,event):
         self.eventBuffer.append(event)
 
-    def clearEventBuffer(self):
+    def clearEventBuffer(self, call_proc_events=True):
+        if call_proc_events is True:
+            self.processDeviceEvents()
         l= len(self.eventBuffer)
         self.eventBuffer.clear()
         return l
@@ -890,7 +898,7 @@ class ioServer(object):
                         psychopy.iohub.MessageDialog("PsychoPy Process dead. Should shut down.")
                         self.shutdown()
                         sys.exit(1)
-                except:
+                except Exception:
                         sys.exit(2)
             gevent.sleep(sleep_interval)
 
@@ -901,12 +909,13 @@ class ioServer(object):
             if Computer.system=='linux2':
                 if self._hookManager:
                     self._hookManager.cancel()
+
             elif Computer.system=='win32':
-                if self._hookDevice and self._hookDevice._hookManager:
-                    #self._hookDevice._hookManager = None #.UnhookMouse()
-                    #self._hookDevice._hookManager.UnhookKeyboard()
-                    self._hookDevice._hookManager = None
-                    self._hookDevice = None
+                del self._hookManager
+                #if self._hookManager:
+                #    self._hookManager.UnhookMouse()
+                #    self._hookManager.UnhookKeyboard()
+
                     
             while len(self.deviceMonitors) > 0:
                 m=self.deviceMonitors.pop(0)
@@ -917,7 +926,7 @@ class ioServer(object):
 
             try:
                 self.closeDataStoreFile()
-            except:
+            except Exception:
                 pass
 
             while len(self.devices) > 0:
@@ -925,9 +934,9 @@ class ioServer(object):
                 try:
                     if d is not None:
                         d._close()
-                except:
+                except Exception:
                         pass
-        except:
+        except Exception:
             print2err("Error in ioSever.shutdown():")
             printExceptionDetailsToStdErr()
             
