@@ -4,7 +4,8 @@
 # Copyright (C) 2015 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
-'''Wrapper for all miscellaneous functions and classes from psychopy.tools'''
+"""Wrapper for all miscellaneous functions and classes from psychopy.tools
+"""
 
 # pylint: disable=W0611
 # W0611 = Unused import %s
@@ -12,7 +13,8 @@
 from psychopy.tools.arraytools import (createXYs, extendArr, makeRadialMatrix,
                                        ratioRange, shuffleArray, val2array)
 
-from psychopy.tools.attributetools import attributeSetter, setAttribute, logAttrib
+from psychopy.tools.attributetools import (attributeSetter, setAttribute,
+                                           logAttrib)
 
 from psychopy.tools.colorspacetools import (dkl2rgb, dklCart2rgb,
                                             hsv2rgb, lms2rgb,
