@@ -1,10 +1,8 @@
 
+import pytest
 from psychopy.visual import Window
 from psychopy.visual.windowframepack import ProjectorFramePacker
 
-from psychopy.constants import *
-import pytest
-
 """define ProjectorFramePack configurations, test the logic
 
     test:
@@ -14,7 +12,7 @@ import pytest
 
 
 @pytest.mark.projectorframepacker
-class Test_class_ProjectorFramePacker:
+class Test_class_ProjectorFramePacker(object):
     """
     """
     def setup_class(self):
@@ -43,4 +41,3 @@ if __name__ == '__main__':
     finalFPS = cls.win.fps()
     print('finalFPS = ' + str(finalFPS))
     cls.teardown_class()
-
