@@ -23,13 +23,17 @@ def array2image(a):
     # fredrik@pythonware.com
     # http://www.pythonware.com
     #
-    if a.dtype.kind in ['u','I', 'B']:
-            mode = "L"
+    if a.dtype.kind in ['u', 'I', 'B']:
+        mode = "L"
     elif a.dtype.kind == numpy.float32:
-            mode = "F"
+        mode = "F"
     else:
-            raise ValueError, "unsupported image mode"
-    return Image.fromstring(mode, (a.shape[1], a.shape[0]), a.tostring())
+        raise ValueError, "unsupported image mode"
+    try:
+        im = Image.fromstring(mode, (a.shape[1], a.shape[0]), a.tostring())
+    except Exception:
+        im = Image.frombytes(mode, (a.shape[1], a.shape[0]), a.tostring())
+    return im
 
 
 def image2array(im):
@@ -41,11 +45,16 @@ def image2array(im):
 #     http://www.pythonware.com
 
     if im.mode not in ("L", "F"):
-            raise ValueError, "can only convert single-layer images"
+        raise ValueError, "can only convert single-layer images"
+    try:
+        imdata = im.tostring()
+    except Exception:
+        imdata = im.tobytes()
     if im.mode == "L":
-            a = numpy.fromstring(im.tostring(), numpy.uint8)
+        a = numpy.fromstring(imdata, numpy.uint8)
     else:
-            a = numpy.fromstring(im.tostring(), numpy.float32)
+        a = numpy.fromstring(imdata, numpy.float32)
+
     a.shape = im.size[1], im.size[0]
     return a
 
