@@ -23,7 +23,7 @@ import numpy as np
 try:
     import pyo64 as pyo
     have_pyo64 = True
-except:
+except Exception:
     import pyo
     have_pyo64 = False
 
@@ -45,7 +45,8 @@ RATE = 44100  # default sampling rate
 MAX_RECORDING_SEC = 1800
 
 
-class VoiceKeyException(Exception): pass
+class VoiceKeyException(Exception):
+    pass
 
 
 class _BaseVoiceKey(object):
@@ -55,48 +56,52 @@ class _BaseVoiceKey(object):
     (if `file_in` is a valid file).
     Over-ride detect() and other methods as needed. See examples.
     """
+
     def __init__(self, sec=0, file_out='', file_in='', **config):
         """
-    :Parameters:
+        :Parameters:
 
-        sec:
-            duration to record in seconds
-        file_out:
-            name for output filename (for microphone input)
-        file_in:
-            name of input file for sound source (not microphone)
-        config:  kwargs dict of parameters for configuration. defaults are:
+            sec:
+                duration to record in seconds
 
-            'msPerChunk': 2; duration of each real-time analysis chunk, in ms
+            file_out:
+                name for output filename (for microphone input)
 
-            'signaler': default None
+            file_in:
+                name of input file for sound source (not microphone)
 
-            'autosave': True; False means manual saving to a file is still
-                possible (by calling .save() but not called automatically upon
-                stopping
+            config:  kwargs dict of parameters for configuration. defaults are:
 
-            'chnl_in' : microphone channel; see pyo.pa_get_input_devices()
+                'msPerChunk': 2; duration of each real-time analysis chunk, in ms
 
-            'chnl_out': not implemented; output device to use
+                'signaler': default None
 
-            'start': 0, select section from a file based on (start, stop) time
+                'autosave': True; False means manual saving to a file is still
+                    possible (by calling .save() but not called automatically upon
+                    stopping
 
-            'stop': -1, end of file (default)
+                'chnl_in' : microphone channel; see pyo.pa_get_input_devices()
 
-            'vol': 0.99, volume 0..1
+                'chnl_out': not implemented; output device to use
 
-            'low': 100, Hz, low end of bandpass; can vary for M/F speakers
+                'start': 0, select section from a file based on (start, stop) time
 
-            'high': 3000, Hz, high end of bandpass
+                'stop': -1, end of file (default)
 
-            'threshold': 10
+                'vol': 0.99, volume 0..1
 
-            'baseline': 0; 0 = auto-detect; give a non-zero value to use that
+                'low': 100, Hz, low end of bandpass; can vary for M/F speakers
 
-            'more_processing': True; compute more stats per chunk including
-                bandpass; try False if 32-bit python can't keep up
+                'high': 3000, Hz, high end of bandpass
 
-            'zero_crossings': True
+                'threshold': 10
+
+                'baseline': 0; 0 = auto-detect; give a non-zero value to use that
+
+                'more_processing': True; compute more stats per chunk including
+                    bandpass; try False if 32-bit python can't keep up
+
+                'zero_crossings': True
         """
         if not (pyo_server and pyo_server.getIsBooted() and
                 pyo_server.getIsStarted()):
@@ -121,8 +126,8 @@ class _BaseVoiceKey(object):
         self.config = {'msPerChunk': 2,
                        'signaler': None,
                        'autosave': True,
-                       'chnl_in': 0,  #pyo.pa_get_default_input(),
-                       #'chnl_out': 2,  #pyo.pa_get_default_output(),  # not working
+                       'chnl_in': 0,  # pyo.pa_get_default_input()
+                       # 'chnl_out': 2,  # pyo.pa_get_default_output() no go
                        'start': 0,
                        'stop': -1,
                        'vol': 0.99,
@@ -131,8 +136,7 @@ class _BaseVoiceKey(object):
                        'threshold': 10,
                        'baseline': 0,
                        'more_processing': True,
-                       'zero_crossings': True,
-                      }
+                       'zero_crossings': True}
         self.config.update(config)
         self.baseline = self.config['baseline']
         self.bad_baseline = False
@@ -183,7 +187,7 @@ class _BaseVoiceKey(object):
                 self.sec = self.config['stop'] - self.config['start']
             elif self.config['start'] <= self.sec:
                 self.sec = self.sec - self.config['start']
-        self.chunks = int(self.sec * 1000. / self.msPerChunk)  # ideal, no slip
+        self.chunks = int(self.sec * 1000. / self.msPerChunk)  # ideal no slip
         # total chunk count and current-chunk index:
         self.count = 0
 
@@ -232,11 +236,12 @@ class _BaseVoiceKey(object):
             self._baselinetable = pyo.NewTable(length=T_BASELINE_OFF)
 
     def _set_baseline(self):
-        """Set self.baseline = rms(silent period) using data in _baselinetable.
+        """Set self.baseline = rms(silent period) using _baselinetable data.
 
-        Called automatically (via pyo trigger) when the baseline table is full.
-        This is better than using chunks (which have gaps between them) or the
-        whole table (which can be very large = slow to work with).
+        Called automatically (via pyo trigger) when the baseline table
+        is full. This is better than using chunks (which have gaps between
+        them) or the whole table (which can be very large = slow to work
+        with).
         """
         data = np.array(self._baselinetable.getTable())
         tstart = int(T_BASELINE_ON * self.rate)
@@ -249,8 +254,8 @@ class _BaseVoiceKey(object):
         # Dubiously quiet is bad too:
         if segment_power < TOO_QUIET:
             self.stop()
-            msg = 'Baseline period is TOO quiet\n' + \
-                  'wrong input channel selected? device-related initial delay?'
+            msg = ('Baseline period is TOO quiet\nwrong input '
+                   'channel selected? device-related initial delay?')
             raise ValueError(msg)
 
         self.baseline = max(segment_power, 1)
@@ -258,11 +263,12 @@ class _BaseVoiceKey(object):
     def _process(self, chunk):
         """Calculate and store basic stats about the current chunk.
 
-        This gets called every chunk -- keep it efficient, esp with 32-bit python
+        This gets called every chunk -- keep it efficient, esp 32-bit python
         """
         # band-pass filtering:
         if self.config['more_processing']:
-            bp_chunk = bandpass(chunk, self.config['low'], self.config['high'], self.rate)
+            bp_chunk = bandpass(chunk, self.config['low'],
+                                self.config['high'], self.rate)
         else:
             bp_chunk = chunk
 
@@ -360,12 +366,13 @@ class _BaseVoiceKey(object):
 
         # triggers: fill tables, call _do_chunk & _set_baseline:
         self._chunktrig = pyo.Trig()
-        self._chunkrec = pyo.TrigTableRec(self._source,
-                                          self._chunktrig, self._chunktable)
-        self._chunklooper = pyo.TrigFunc(self._chunkrec["trig"], self._do_chunk)
+        self._chunkrec = pyo.TrigTableRec(self._source, self._chunktrig,
+                                          self._chunktable)
+        self._chunklooper = pyo.TrigFunc(self._chunkrec["trig"],
+                                         self._do_chunk)
         self._wholetrig = pyo.Trig()
-        self._wholerec = pyo.TrigTableRec(self._source,
-                                          self._wholetrig, self._wholetable)
+        self._wholerec = pyo.TrigTableRec(self._source, self._wholetrig,
+                                          self._wholetable)
         self._wholestopper = pyo.TrigFunc(self._wholerec["trig"], self.stop)
 
         # skip if a baseline value was given in config:
@@ -381,8 +388,8 @@ class _BaseVoiceKey(object):
         if self.file_in and not silent:
             self._source.out()
 
-        # start calling self._do_chunk by flipping its trigger; _do_chunk then
-        # triggers itself via _chunktrigger until done:
+        # start calling self._do_chunk by flipping its trigger;
+        # _do_chunk then triggers itself via _chunktrigger until done:
         self._chunktrig.play()
         self._wholetrig.play()
         self._baselinetrig.play()
@@ -393,8 +400,8 @@ class _BaseVoiceKey(object):
     def slippage(self):
         """Diagnostic: Ratio of the actual (elapsed) time to the ideal time.
 
-        Ideal ratio = 1 = sample-perfect acquisition of msPerChunk, without any
-        gaps between or within chunks. 1. / slippage is the proportion of
+        Ideal ratio = 1 = sample-perfect acquisition of msPerChunk, without
+        any gaps between or within chunks. 1. / slippage is the proportion of
         samples contributing to chunk stats.
         """
         if len(self.t_enter) > 1:
@@ -411,7 +418,9 @@ class _BaseVoiceKey(object):
         return bool(hasattr(self, '_chunklooper'))  # .start() has been called
 
     def stop(self):
-        """Stop a voice-key in progress. Ends and saves the recording if using microphone input.
+        """Stop a voice-key in progress.
+
+        Ends and saves the recording if using microphone input.
         """
         # Will be stopped at self.count (= the chunk index), but that is less
         # reliable than self.elapsed due to any slippage.
@@ -489,10 +498,11 @@ class _BaseVoiceKey(object):
 
 
 class SimpleThresholdVoiceKey(_BaseVoiceKey):
-    """Class for a simple threshold voice key (loudness-based onset detection).
+    """Class for simple threshold voice key (loudness-based onset detection).
 
     The "hello world" of voice-keys.
     """
+
     def detect(self):
         """Trip if the current chunk's audio power > 10 * baseline loudness.
         """
@@ -508,10 +518,12 @@ class OnsetVoiceKey(_BaseVoiceKey):
     """Class for speech onset detection.
 
     Uses bandpass-filtered signal (100-3000Hz). When the voice key trips,
-    the best voice-onset RT estimate is saved as `self.event_onset`, in seconds.
+    the best voice-onset RT estimate is saved as `self.event_onset`, in sec.
+
     """
+
     def detect(self):
-        """Trip if recent audio power is greater than the baseline for long enough.
+        """Trip if recent audio power is greater than the baseline.
         """
         if self.event_detected or not self.baseline:
             return
@@ -528,6 +540,7 @@ class OnsetVoiceKey(_BaseVoiceKey):
 class OffsetVoiceKey(_BaseVoiceKey):
     """Class to detect the offset of a single-word utterance.
     """
+
     def __init__(self, sec=10, file_out='', file_in='', delay=0.3, **kwargs):
         """Record and ends the recording after speech offset.  When the voice
         key trips, the best voice-offset RT estimate is saved as
@@ -535,7 +548,8 @@ class OffsetVoiceKey(_BaseVoiceKey):
 
         :Parameters:
 
-            `sec`: duration of recording in the absence of speech or other sounds.
+            `sec`: duration of recording in the absence of speech or
+                other sounds.
 
             `delay`: extra time to record after speech offset, default 0.3s.
 
@@ -544,8 +558,7 @@ class OffsetVoiceKey(_BaseVoiceKey):
         config = {'sec': sec,
                   'file_out': file_out,
                   'file_in': file_in,
-                  'delay': delay,
-                 }
+                  'delay': delay}
         kwargs.update(config)
         super(OffsetVoiceKey, self).__init__(**kwargs)
 
@@ -565,9 +578,9 @@ class OffsetVoiceKey(_BaseVoiceKey):
         elif not self.event_offset:
             window = 25
             threshold = 10 * self.baseline
-            #segment = np.array(self.power_bp[-window:])
+            # segment = np.array(self.power_bp[-window:])
             conditions = all([x < threshold for x in self.power_bp[-window:]])
-            #conditions = np.all(segment < threshold)
+            # conditions = np.all(segment < threshold)
             if conditions:
                 self.event_lag = window * self.msPerChunk / 1000.
                 self.event_offset = self.elapsed - self.event_lag
@@ -577,7 +590,7 @@ class OffsetVoiceKey(_BaseVoiceKey):
             self.stop()
 
 
-### ----- Convenience classes -------------------------------------------------
+# ----- Convenience classes -------------------------------------------------
 
 class Recorder(_BaseVoiceKey):
     """Convenience class: microphone input only (no real-time analysis).
@@ -587,23 +600,29 @@ class Recorder(_BaseVoiceKey):
     `.start().join()` will not do so). This might be especially useful when
     making long recordings.
     """
+
     def __init__(self, sec=2, filename='rec.wav'):
         super(Recorder, self).__init__(sec, file_out=filename)
-    #def _set_defaults(self):
+    # def _set_defaults(self):
     #    pass
+
     def __del__(self):
         if hasattr(self, 'filename') and not os.path.isfile(self.filename):
             self.save()
+
     def _set_baseline(self):
         pass
+
     def detect(self):
         pass
+
     def _process(self, *args, **kwargs):
         pass
+
     def record(self, sec=None):
         try:
             self.start().join(sec)
-        except:
+        except Exception:
             self.save()
             raise
 
@@ -611,6 +630,7 @@ class Recorder(_BaseVoiceKey):
 class Player(_BaseVoiceKey):
     """Convenience class: sound output only (no real-time analysis).
     """
+
     def __init__(self, sec=None, source='rec.wav',
                  start=0, stop=-1, rate=44100):
         if type(source) in [np.ndarray]:
@@ -620,19 +640,23 @@ class Player(_BaseVoiceKey):
         config = {'start': start,
                   'stop': stop}
         super(Player, self).__init__(sec, file_in=source, **config)
-    #def _set_defaults(self):  # ideally override but need more refactoring
+    # def _set_defaults(self):  # ideally override but need more refactoring
     #    pass
+
     def _set_baseline(self):
         pass
+
     def detect(self):
         pass
+
     def _process(self, *args, **kwargs):
         pass
+
     def play(self, sec=None):
         self.start().join(sec)
 
 
-### ----- pyo initialization (essential) -------------------------------------
+# ----- pyo initialization (essential) -------------------------------------
 
 def pyo_init(rate=44100, nchnls=1, buffersize=32, duplex=1):
     """Start and boot a global pyo server, restarting if needed.
@@ -644,7 +668,7 @@ def pyo_init(rate=44100, nchnls=1, buffersize=32, duplex=1):
     # re-init
     if hasattr(pyo_server, 'shutdown'):
         pyo_server.stop()
-        sleep(0.25)  #make sure enough time passes for the server to shutdown
+        sleep(0.25)  # make sure enough time passes for the server to shutdown
         pyo_server.shutdown()
         sleep(0.25)
         pyo_server.reinit(sr=rate, nchnls=nchnls,
