@@ -12,12 +12,14 @@ from . vk_tools import get_time, sleep
 try:
     from psychopy import parallel
     have_parallel = True
-except:  # ImportError:
+except Exception:  # ImportError:
     have_parallel = False
 
+
 class ParallelVoiceKeySignal(_BaseVoiceKeySignal):
     """Class for using PsychoPy parallel as a signal channel.
     """
+
     def __init__(self, sec=0.010, delay=0, on=1, off=0, address=0x378, pin=2):
         if not have_parallel:
             raise ImportError("could not import parallel (for signaler)")
