@@ -7,10 +7,13 @@
 # Copyright (C) 2015 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
-import os, sys, time
-import hashlib, base64
-import httplib, mimetypes  # deprecated; use requests package instead
-import socket, re
+import os
+import sys
+import base64
+import httplib
+import mimetypes  # deprecated; use requests package instead
+import socket
+import re
 from psychopy import logging
 from psychopy.constants import PSYCHOPY_USERAGENT
 from psychopy import prefs
@@ -20,31 +23,37 @@ if sys.version_info >= (3, 0):
 else:
     py3 = False
 if py3:
-    import urllib.request, urllib.error, urllib.parse
-    import io
+    import urllib.request
+    import urllib.error
+    import urllib.parse
+    import io  # pylint: disable=W0611
 else:
     import urllib2
+
     class FakeURLlib(object):
+
         def __init__(self, lib):
             self.request = lib
             self.error = lib
             self.parse = lib
     urllib = FakeURLlib(urllib2)
-    import cStringIO as io
+    import cStringIO as io  # pylint: disable=W0611
 
-TIMEOUT = max(prefs.connections['timeout'], 2.0) # default 20s from prefs, min 2s
+# default 20s from prefs, min 2s
+TIMEOUT = max(prefs.connections['timeout'], 2.0)
 socket.setdefaulttimeout(TIMEOUT)
 
-global proxies
-proxies = None #if this is populated then it has been set up already
+# global proxies
+proxies = None  # if this is populated then it has been set up already
 
 
 class NoInternetAccessError(Exception):
     """An internet connection is required but not available
     """
-global haveInternet
+# global haveInternet
 haveInternet = None  # gets set True or False when you check
 
+
 def haveInternetAccess(forceCheck=False):
     """Detect active internet connection or fail quickly.
 
@@ -60,12 +69,14 @@ def haveInternetAccess(forceCheck=False):
                     urllib.request.urlopen(site, timeout=wait)
                     haveInternet = True  # cache
                     return True  # one success is good enough
-                except:  # urllib.error.URLError:  # socket.timeout() was happening to some people some of the time
+                except Exception:  # urllib.error.URLError:
+                    #  socket.timeout() can also happen
                     pass
         else:
             haveInternet = False
     return haveInternet
 
+
 def requireInternetAccess(forceCheck=False):
     """Checks for access to the internet, raise error if no access.
     """
@@ -75,11 +86,13 @@ def requireInternetAccess(forceCheck=False):
         raise NoInternetAccessError(msg)
     return True
 
+
 def tryProxy(handler, URL=None):
     """
     Test whether we can connect to a URL with the current proxy settings.
 
-    `handler` can be typically `web.proxies`, if `web.setupProxy()` has been run.
+    `handler` can be typically `web.proxies`, if `web.setupProxy()` has been
+    run.
 
     :Returns:
 
@@ -89,78 +102,84 @@ def tryProxy(handler, URL=None):
 
     """
     if URL is None:
-        URL='http://www.google.com'#hopefully google isn't down!
+        URL = 'http://www.google.com'  # hopefully google isn't down!
     req = urllib.request.Request(URL)
     opener = urllib.request.build_opener(handler)
     try:
-        opener.open(req, timeout=2).read(5)#open and read a few characters
+        opener.open(req, timeout=2).read(5)  # open and read a few characters
         return True
     except urllib.error.URLError as err:
         return err
     except urllib.error.HTTPError as err:
         return err
 
+
 def getPacFiles():
     """Return a list of possible auto proxy .pac files being used,
     based on the system registry (win32) or system preferences (OSX).
     """
-    pacFiles=[]
-    if sys.platform=='win32':
+    pacFiles = []
+    if sys.platform == 'win32':
         try:
-            import _winreg as winreg#used from python 2.0-2.6
-        except:
-            import winreg#used from python 2.7 onwards
+            import _winreg as winreg  # used from python 2.0-2.6
+        except ImportError:
+            import winreg  # used from python 2.7 onwards
         net = winreg.OpenKey(
             winreg.HKEY_CURRENT_USER,
-            "Software\\Microsoft\\Windows\\CurrentVersion\\Internet Settings"
-        )
+            "Software\\Microsoft\\Windows\\CurrentVersion\\Internet Settings")
         nSubs, nVals, lastMod = winreg.QueryInfoKey(net)
-        subkeys={}
+        subkeys = {}
         for i in range(nVals):
-            thisName, thisVal, thisType=winreg.EnumValue(net,i)
-            subkeys[thisName]=thisVal
-        if 'AutoConfigURL' in subkeys.keys() and len(subkeys['AutoConfigURL'])>0:
+            thisName, thisVal, thisType = winreg.EnumValue(net, i)
+            subkeys[thisName] = thisVal
+        if ('AutoConfigURL' in subkeys.keys() and
+                len(subkeys['AutoConfigURL']) > 0):
             pacFiles.append(subkeys['AutoConfigURL'])
-    elif sys.platform=='darwin':
+    elif sys.platform == 'darwin':
         import plistlib
-        sysPrefs = plistlib.readPlist('/Library/Preferences/SystemConfiguration/preferences.plist')
-        networks=sysPrefs['NetworkServices']
-        #loop through each possible network (e.g. Ethernet, Airport...)
+        sysPrefs = plistlib.readPlist('/Library/Preferences/System'
+                                      'Configuration/preferences.plist')
+        networks = sysPrefs['NetworkServices']
+        # loop through each possible network (e.g. Ethernet, Airport...)
         for network in networks.items():
-            netKey, network=network#the first part is a long identifier
+            netKey, network = network  # the first part is a long identifier
             if 'ProxyAutoConfigURLString' in network['Proxies'].keys():
                 pacFiles.append(network['Proxies']['ProxyAutoConfigURLString'])
-    return list(set(pacFiles)) # remove redundant ones
+    return list(set(pacFiles))  # remove redundant ones
+
 
 def getWpadFiles():
-    """
-    Return possible pac file locations from the standard set of .wpad locations
+    """Return possible pac file locations from the standard set of .wpad
+    locations
 
     NB this method only uses the DNS method to search, not DHCP queries, and
     so may not find all possible .pac locations.
 
     See http://en.wikipedia.org/wiki/Web_Proxy_Autodiscovery_Protocol
     """
-    #pacURLs.append("http://webproxy."+domain+"/wpad.dat")
-    # for me finds a file that starts: function FindProxyForURL(url,host) { ... }
-    # dynamcially chooses a proxy based on the requested url and host; how to parse?
+    # pacURLs.append("http://webproxy."+domain+"/wpad.dat")
+    # for me finds a file that starts: function FindProxyForURL(url,host)
+    # dynamcially chooses a proxy based on the requested url and host; how to
+    # parse?
 
     domainParts = socket.gethostname().split('.')
-    pacURLs=[]
+    pacURLs = []
     for ii in range(len(domainParts)):
         domain = '.'.join(domainParts[ii:])
-        pacURLs.append("http://wpad."+domain+"/wpad.dat")
-    return list(set(pacURLs)) # remove redundant ones
+        pacURLs.append("http://wpad." + domain + "/wpad.dat")
+    return list(set(pacURLs))  # remove redundant ones
 
-def proxyFromPacFiles(pacURLs=[], URL=None, log=True):
+
+def proxyFromPacFiles(pacURLs=None, URL=None, log=True):
     """Attempts to locate and setup a valid proxy server from pac file URLs
 
     :Parameters:
 
         - pacURLs : list
 
-            List of locations (URLs) to look for a pac file. This might come from
-            :func:`~psychopy.web.getPacFiles` or :func:`~psychopy.web.getWpadFiles`.
+            List of locations (URLs) to look for a pac file. This might
+            come from :func:`~psychopy.web.getPacFiles` or
+            :func:`~psychopy.web.getWpadFiles`.
 
         - URL : string
 
@@ -168,49 +187,58 @@ def proxyFromPacFiles(pacURLs=[], URL=None, log=True):
 
     :Returns:
 
-        - A urllib.request.ProxyHandler if successful (and this will have been added as
-        an opener to the urllib)
-        - False if no proxy was found in the files that allowed successful connection
+        - A urllib.request.ProxyHandler if successful (and this will have
+          been added as an opener to the urllib)
+        - False if no proxy was found in the files that allowed successful
+          connection
     """
 
-    if pacURLs==[]:#if given none try to find some
+    if pacURLs == None:  # if given none try to find some
         pacURLs = getPacFiles()
-    if pacURLs==[]:#if still empty search for wpad files
+    if pacURLs == []:  # if still empty search for wpad files
         pacURLs = getWpadFiles()
-        #for each file search for valid urls and test them as proxies
+        # for each file search for valid urls and test them as proxies
     for thisPacURL in pacURLs:
         if log:
-            logging.debug('proxyFromPacFiles is searching file:\n  %s' %thisPacURL)
+            msg = 'proxyFromPacFiles is searching file:\n  %s'
+            logging.debug(msg % thisPacURL)
         try:
             response = urllib.request.urlopen(thisPacURL, timeout=2)
         except urllib.error.URLError:
             if log:
-                logging.debug("Failed to find PAC URL '%s' " %thisPacURL)
+                logging.debug("Failed to find PAC URL '%s' " % thisPacURL)
             continue
         pacStr = response.read()
-        #find the candidate PROXY strings (valid URLS), numeric and non-numeric:
-        possProxies = re.findall(r"PROXY\s([^\s;,:]+:[0-9]{1,5})[^0-9]", pacStr+'\n')
+        # find the candidate PROXY strings (valid URLS), numeric and
+        # non-numeric:
+        pattern = r"PROXY\s([^\s;,:]+:[0-9]{1,5})[^0-9]"
+        possProxies = re.findall(pattern, pacStr + '\n')
         for thisPoss in possProxies:
             proxUrl = 'http://' + thisPoss
-            handler=urllib.request.ProxyHandler({'http':proxUrl})
-            if tryProxy(handler)==True:
+            handler = urllib.request.ProxyHandler({'http': proxUrl})
+            if tryProxy(handler) == True:
                 if log:
-                    logging.debug('successfully loaded: %s' %proxUrl)
-                urllib.request.install_opener(urllib.request.build_opener(handler))
+                    logging.debug('successfully loaded: %s' % proxUrl)
+                opener = urllib.request.build_opener(handler)
+                urllib.request.install_opener(opener)
                 return handler
     return False
 
+
 def setupProxy(log=True):
     """Set up the urllib proxy if possible.
 
-     The function will use the following methods in order to try and determine proxies:
-        #. standard urllib.request.urlopen (which will use any statically-defined http-proxy settings)
+     The function will use the following methods in order to try and
+     determine proxies:
+        #. standard urllib.request.urlopen (which will use any
+           statically-defined http-proxy settings)
         #. previous stored proxy address (in prefs)
         #. proxy.pac files if these have been added to system settings
         #. auto-detect proxy settings (WPAD technology)
 
      .. note:
-        This can take time, as each failed attempt to set up a proxy involves trying to load a URL and timing out. Best
+        This can take time, as each failed attempt to set up a proxy
+        involves trying to load a URL and timing out. Best
         to do in a separate thread.
 
     :Returns:
@@ -218,70 +246,90 @@ def setupProxy(log=True):
         True (success) or False (failure)
     """
     global proxies
-    #try doing nothing
-    proxies=urllib.request.ProxyHandler(urllib.request.getproxies())
+    # try doing nothing
+    proxies = urllib.request.ProxyHandler(urllib.request.getproxies())
     if tryProxy(proxies) is True:
         if log:
-            logging.debug("Using standard urllib (static proxy or no proxy required)")
-        urllib.request.install_opener(urllib.request.build_opener(proxies))#this will now be used globally for ALL urllib opening
+            logging.debug("Using standard urllib (static proxy or "
+                          "no proxy required)")
+        # this will now be used globally for ALL urllib opening
+        urllib.request.install_opener(urllib.request.build_opener(proxies))
         return 1
 
-    #try doing what we did last time
-    if len(prefs.connections['proxy'])>0:
-        proxies=urllib.request.ProxyHandler({'http': prefs.connections['proxy']})
+    # try doing what we did last time
+    if len(prefs.connections['proxy']) > 0:
+        proxConnPref = {'http': prefs.connections['proxy']}
+        proxies = urllib.request.ProxyHandler(proxConnPref)
         if tryProxy(proxies) is True:
             if log:
-                logging.debug('Using %s (from prefs)' %(prefs.connections['proxy']))
-            urllib.request.install_opener(urllib.request.build_opener(proxies))#this will now be used globally for ALL urllib opening
+                msg = 'Using %s (from prefs)'
+                logging.debug(msg % prefs.connections['proxy'])
+            # this will now be used globally for ALL urllib opening
+            opener = urllib.request.build_opener(proxies)
+            urllib.request.install_opener(opener)
             return 1
         else:
             if log:
                 logging.debug("Found a previous proxy but it didn't work")
 
-    #try finding/using a proxy.pac file
-    pacURLs=getPacFiles()
+    # try finding/using a proxy.pac file
+    pacURLs = getPacFiles()
     if log:
-        logging.debug("Found proxy PAC files: %s" %pacURLs)
-    proxies=proxyFromPacFiles(pacURLs) # installs opener, if successful
-    if proxies and hasattr(proxies, 'proxies') and len(proxies.proxies['http'])>0:
-        #save that proxy for future
-        prefs.connections['proxy']=proxies.proxies['http']
+        logging.debug("Found proxy PAC files: %s" % pacURLs)
+    proxies = proxyFromPacFiles(pacURLs)  # installs opener, if successful
+    if (proxies and
+            hasattr(proxies, 'proxies') and
+            len(proxies.proxies['http']) > 0):
+        # save that proxy for future
+        prefs.connections['proxy'] = proxies.proxies['http']
         prefs.saveUserPrefs()
         if log:
-            logging.debug('Using %s (from proxy PAC file)' %(prefs.connections['proxy']))
+            msg = 'Using %s (from proxy PAC file)'
+            logging.debug(msg % prefs.connections['proxy'])
         return 1
 
-    #try finding/using 'auto-detect proxy'
-    pacURLs=getWpadFiles()
-    proxies=proxyFromPacFiles(pacURLs) # installs opener, if successful
-    if proxies and hasattr(proxies, 'proxies') and len(proxies.proxies['http'])>0:
-        #save that proxy for future
-        prefs.connections['proxy']=proxies.proxies['http']
+    # try finding/using 'auto-detect proxy'
+    pacURLs = getWpadFiles()
+    proxies = proxyFromPacFiles(pacURLs)  # installs opener, if successful
+    if (proxies and
+            hasattr(proxies, 'proxies') and
+            len(proxies.proxies['http']) > 0):
+        # save that proxy for future
+        prefs.connections['proxy'] = proxies.proxies['http']
         prefs.saveUserPrefs()
         if log:
-            logging.debug('Using %s (from proxy auto-detect)' %(prefs.connections['proxy']))
+            msg = 'Using %s (from proxy auto-detect)'
+            logging.debug(msg % prefs.connections['proxy'])
         return 1
 
-    proxies=0
+    proxies = 0
     return 0
 
-### post_multipart is from {{{ http://code.activestate.com/recipes/146306/ (r1) ###
-def _post_multipart(host, selector, fields, files, encoding='utf-8', timeout=TIMEOUT,
-                    userAgent=PSYCHOPY_USERAGENT, basicAuth=None, https=False):
-    """
-    Post fields and files to an http host as multipart/form-data.
+# post_multipart is from {{{ http://code.activestate.com/recipes/146306/
+# (r1) ###
+
+
+def _post_multipart(host, selector, fields, files,
+                    encoding='utf-8', timeout=TIMEOUT,
+                    userAgent=PSYCHOPY_USERAGENT,
+                    basicAuth=None, https=False):
+    """Post fields and files to an http host as multipart/form-data.
     fields is a sequence of (name, value) elements for regular form fields.
-    file is a 1-item sequence of (name, filename, value) elements for data to be uploaded as files
+    file is a 1-item sequence of (name, filename, value) elements for data
+    to be uploaded as files
+
     Return the server's response page.
     """
     # as updated for HTTPConnection()
-    # as rewritten for any encoding http://www.nerdwho.com/blog/57/enviando-arquivos-e-dados-ao-mesmo-tempo-via-http-post-usando-utf-8/
+    # as rewritten for any encoding http://www.nerdwho.com/blog/57/
+    #     enviando-arquivos-e-dados-ao-mesmo-tempo-via-http-post-usando-utf-8/
     # JRG: added timeout, userAgent, basic auth, https
 
     def _encode_multipart_formdata(fields, files, encoding='utf-8'):
-        """
-        fields is a sequence of (name, value) elements for regular form fields.
-        files is a sequence of (name, filename, value) elements for data to be uploaded as files
+        """fields is a sequence of (name, value) elements for regular
+        form fields. files is a sequence of (name, filename, value)
+        elements for data to be uploaded as files
+
         Return (content_type, body) ready for httplib.HTTP instance
         """
         BOUNDARY = u'----------ThIs_Is_tHe_bouNdaRY_$'
@@ -298,8 +346,10 @@ def _post_multipart(host, selector, fields, files, encoding='utf-8', timeout=TIM
 
         for (key, filename, value) in files:
             L.append(u'--' + BOUNDARY)
-            L.append(u'Content-Disposition: form-data; name="%s"; filename="%s"' % (key, filename))
-            L.append(u'Content-Type: %s;charset=%s' % (_get_content_type(filename), encoding))
+            msg = u'Content-Disposition: form-data; name="%s"; filename="%s"'
+            L.append(msg % (key, filename))
+            msg = u'Content-Type: %s;charset=%s'
+            L.append(msg % (_get_content_type(filename), encoding))
             L.append(u'Content-Transfer-Encoding: base64')
             L.append(u'')
             L.append(base64.b64encode(value).decode())
@@ -324,8 +374,7 @@ def _post_multipart(host, selector, fields, files, encoding='utf-8', timeout=TIM
         conn = httplib.HTTPConnection(host, timeout=timeout)
     headers = {u'User-Agent': userAgent,
                u'Charset': encoding,
-               u'Content-Type': content_type,
-               }
+               u'Content-Type': content_type}
     # apache basic auth (sent in clear text, https can help):
     if basicAuth and type(basicAuth) == str:
         user_cred = base64.encodestring(basicAuth).replace('\n', '')
@@ -333,54 +382,62 @@ def _post_multipart(host, selector, fields, files, encoding='utf-8', timeout=TIM
 
     try:
         conn.request(u'POST', selector, body, headers)
-    except: # ? don't seem to get a proper exception
-        return -1, 'connection error (possible timeout after %ss)' % str(timeout), 'timeout or error'
+    except Exception:  # ? don't seem to get a proper exception
+        msg = 'connection error (possible timeout after %ss)'
+        return -1, msg % str(timeout), 'timeout or error'
 
     try:
         result = conn.getresponse()
-    except:
-        return -1, 'connection error (can be "socket.error: [Errno 54] Connection reset by peer")'
+    except Exception:
+        return -1, ('connection error (can be "socket.error: '
+                    '[Errno 54] Connection reset by peer")')
     return result.status, result.reason, result.read()
 
-    ## end of http://code.activestate.com/recipes/146306/ }}}
+    # end of http://code.activestate.com/recipes/146306/ }}}
 
-def upload(selector, filename, basicAuth=None, host=None, https=False, log=True):
-    """DEPRECATED: Upload a local file over the internet to a configured http server.
+
+def upload(selector, filename, basicAuth=None, host=None,
+           https=False, log=True):
+    """DEPRECATED: Upload a local file over the internet to a
+    configured http server.
     Use the requests package instead. See http://www.python-requests.org/
 
-    This method handshakes with a php script on a remote server to transfer a local
-    file to another machine via http (using POST).
+    This method handshakes with a php script on a remote server to transfer
+    a local file to another machine via http (using POST).
 
-    Returns "success" plus a sha256 digest of the file on the server and a byte count.
-    If the upload was not successful, an error code is returned (eg, "too_large" if the
-    file size exceeds the limit specified server-side in up.php, or "no_file" if there
-    was no POST attachment).
+    Returns "success" plus a sha256 digest of the file on the server and
+    a byte count. If the upload was not successful, an error code is
+    returned (eg, "too_large" if the file size exceeds the limit specified
+    server-side in up.php, or "no_file" if there was no POST attachment).
 
     .. note::
-        The server that receives the files needs to be configured before uploading
-        will work. php files and notes for a sys-admin are included in `psychopy/contrib/http/`.
-        In particular, the php script `up.php` needs to be copied to the server's
-        web-space, with appropriate permissions and directories, including apache
-        basic auth and https (if desired). The maximum size for an upload can be configured within up.php
+        The server that receives the files needs to be configured before
+        uploading will work. php files and notes for a sys-admin are
+        included in `psychopy/contrib/http/`. In particular, the php script
+        `up.php` needs to be copied to the server's web-space, with
+        appropriate permissions and directories, including apache basic
+        auth and https (if desired). The maximum size for an upload can
+        be configured within up.php
 
     **Parameters:**
 
         `selector` : (required, string)
-            a standard URL of the form `http://host/path/to/up.php`, e.g., `http://upload.psychopy.org/test/up.php`
+            a standard URL of the form `http://host/path/to/up.php`,
+            e.g., `http://upload.psychopy.org/test/up.php`
 
             .. note::
                 Limited https support is provided (see below).
 
         `filename` : (required, string)
-            the path to the local file to be transferred. The file can be any format:
-            text, utf-8, binary. All files are hex encoded while in transit (increasing
-            the effective file size).
+            the path to the local file to be transferred. The file can be
+            any format: text, utf-8, binary. All files are hex encoded while
+            in transit (increasing the effective file size).
 
             .. note::
                 Encryption (*beta*) is available as a separate step. That is,
                 first :mod:`~psychopy.contrib.opensslwrap.encrypt()` the file,
-                then :mod:`~psychopy.web.upload()` the encrypted file in the same
-                way that you would any other file.
+                then :mod:`~psychopy.web.upload()` the encrypted file in the
+                same way that you would any other file.
 
         `basicAuth` : (optional)
             apache 'user:password' string for basic authentication. If a `basicAuth`
@@ -407,24 +464,29 @@ def upload(selector, filename, basicAuth=None, host=None, https=False, log=True)
     Author: Jeremy R. Gray, 2012
     """
 
-    logging.warning("Deprecated: psychopy.web.upload is superceded by requests (python package)")
+    logging.warning(
+        "Deprecated: psychopy.web.upload is superceded by requests (python package)")  # ~Nov 2015
 
     requireInternetAccess()  # needed to upload over http
 
     fields = [('name', 'PsychoPy_upload'), ('type', 'file')]
     if not selector:
         logging.error('upload: need a selector, http://<host>/path/to/up.php')
-        raise ValueError('upload: need a selector, http://<host>/path/to/up.php')
+        raise ValueError(
+            'upload: need a selector, http://<host>/path/to/up.php')
     if not host:
         host = selector.split('/')[2]
         if log:
             logging.info('upload: host extracted from selector = %s' % host)
     if selector.startswith('https'):
         if https is not True:
-            logging.error('upload: https not explicitly requested. use https=True to proceed anyway (see API for security caveats).')
-            raise ValueError('upload: https not fully supported (see API for caveats and usage), exiting.')
+            logging.error(
+                'upload: https not explicitly requested. use https=True to proceed anyway (see API for security caveats).')
+            raise ValueError(
+                'upload: https not fully supported (see API for caveats and usage), exiting.')
         elif log:
-            logging.exp('upload: https requested; note that security is not fully assured (see API)')
+            logging.exp(
+                'upload: https requested; note that security is not fully assured (see API)')
     elif https:
         msg = 'upload: to use https, the selector URL must start with "https"'
         logging.error(msg)
@@ -432,12 +494,14 @@ def upload(selector, filename, basicAuth=None, host=None, https=False, log=True)
     if not os.path.isfile(filename):
         logging.error('upload: file not found (%s)' % filename)
         raise ValueError('upload: file not found (%s)' % filename)
-    contents = open(filename).read() # base64 encoded in _encode_multipart_formdata()
+    # base64 encoded in _encode_multipart_formdata()
+    contents = open(filename).read()
     file = [('file_1', filename, contents)]
 
     # initiate the POST:
     if log:
-        logging.exp('upload: uploading file %s to %s' % (os.path.abspath(filename), selector))
+        logging.exp('upload: uploading file %s to %s' %
+                    (os.path.abspath(filename), selector))
     try:
         status, reason, result = _post_multipart(host, selector, fields, file,
                                                  basicAuth=basicAuth, https=https)
@@ -452,11 +516,11 @@ def upload(selector, filename, basicAuth=None, host=None, https=False, log=True)
     # process the result:
     if status == 200:
         result_fields = result.split()
-        #result = 'status_msg digest' # if using up.php
+        # result = 'status_msg digest' # if using up.php
         if result_fields[0] == 'good_upload':
-            outcome = 'success'+' '+result
+            outcome = 'success' + ' ' + result
         else:
-            outcome = result # failure code
+            outcome = result  # failure code
     elif status == 404:
         outcome = '404 Not_Found: server config error'
     elif status == 403:
