@@ -3,7 +3,7 @@
 echo DID YOU UPDATE THE CHANGELOG?
 python setup.py sdist --format=zip
 python setup.py egg_info
-python setup.py bdist_egg
+python setup.py bdist_wheel
 
 echo register with;
 echo python setup.py register
